Module from_row

Module from_row 

Functions

reflexive
sqlx_from_row
rely on Sqlx’s FromRow trait to convert a row I put this on its own method because sometime I rely on more dynamic ways to convert a row and I want to keep sqlx’s trait separate